@@ -1,9 +1,9 @@
-#![doc(html_root_url = "https://sfackler.github.io/rust-security-framework/doc/v0.2")]
 #![allow(bad_style)]
 
-extern crate MacTypes_sys;
 extern crate core_foundation_sys;
-extern crate libc;
+
+#[cfg_attr(any(target_os = "macos", target_os = "ios"), link(name = "Security", kind = "framework"))]
+extern "C" {}
 
 #[cfg(target_os = "macos")]
 pub mod access;
@@ -30,3 +30,4 @@ pub mod secure_transport;
 #[cfg(target_os = "macos")]
 pub mod transform;
 pub mod trust;
+pub mod trust_settings;
